/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kubrickui.rc
  0x0,0x0,0x2,0xaf,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x48,0x8,0x2d,0x15,0x0,0xe6,0x1d,0x5b,0x20,0x10,0x97,0x1b,
  0xdb,0x5a,0x66,0x32,0x24,0xa2,0xe7,0x22,0x1e,0x66,0x43,0x6c,0x7e,0xf1,0x48,0x7e,
  0x38,0x9c,0xc9,0xd9,0xac,0x2a,0x12,0x55,0x55,0x4d,0x22,0x5,0x1,0x56,0x0,0x52,
  0x0,0x4f,0x0,0x5b,0x6b,0xd7,0xa6,0x62,0xf9,0xc0,0x83,0xc1,0x80,0x48,0x74,0xd2,
  0x4b,0x8c,0xc2,0x1,0xca,0x9b,0x89,0xa0,0x63,0x36,0x62,0x34,0xbe,0xc3,0xcc,0xd6,
  0x42,0x63,0xa2,0x42,0xd7,0x75,0x10,0x32,0xb8,0x7f,0x8d,0x2b,0xa7,0x86,0x17,0x60,
  0xd1,0x25,0x2d,0xe8,0x8a,0xb8,0xea,0x2d,0xd2,0x27,0x6f,0x46,0x5,0x1c,0xf,0x5e,
  0x10,0x28,0x9c,0xe,0x57,0x19,0x95,0x58,0xbd,0x68,0x3f,0x36,0x14,0xe,0x5c,0xd1,
  0x2a,0xdd,0x36,0xe9,0xcd,0xad,0xf4,0xa0,0x2,0xfc,0x36,0xbe,0xb7,0xb5,0xb8,0x33,
  0xdb,0x1b,0x46,0x9b,0xe3,0x22,0xa9,0x6e,0x90,0x6a,0xd0,0xbd,0xac,0xae,0xa9,0x65,
  0xc2,0x6c,0xd4,0xac,0xaf,0x14,0xf2,0xbb,0x9c,0x96,0xc9,0x63,0x5f,0x10,0xa,0x0,
  0xa9,0xe6,0x4c,0x9c,0x87,0x69,0x70,0x5b,0x14,0x38,0xbe,0xd4,0x4f,0x3d,0x7,0x7b,
  0xcf,0xd3,0xe9,0x72,0x80,0xcc,0x61,0x63,0xe4,0xd2,0xb6,0x30,0xe6,0xa5,0xc2,0xb,
  0x7c,0xbc,0x6a,0xc5,0x19,0xd2,0xfb,0xa2,0x92,0x10,0x3,0x95,0xf6,0x98,0xf4,0xcc,
  0x79,0x43,0x8f,0x4d,0x93,0x56,0xae,0xbe,0xd4,0x1c,0x5a,0x2f,0xf9,0x98,0xca,0xb8,
  0xcd,0x5a,0x39,0x54,0x80,0x21,0xcf,0x50,0xe8,0x6a,0x6e,0x69,0xd7,0xc7,0x8e,0x3d,
  0xa3,0xf2,0xbf,0xdd,0x6a,0x52,0xb5,0xdc,0x59,0x37,0xef,0x5d,0x56,0x9c,0xda,0xfe,
  0x8f,0x98,0x67,0xfa,0x6f,0x6b,0x4d,0xea,0xd6,0x58,0x2,0x71,0xb0,0x9a,0xf6,0xe5,
  0x5d,0x4b,0x92,0x35,0x67,0xb4,0x2a,0xd6,0x16,0xbe,0x1,0x87,0xbc,0x99,0xdf,0x8f,
  0xbf,0xa1,0x2,0x13,0xd,0x2b,0x28,0xaf,0xd1,0x19,0x7c,0x48,0x6a,0x9b,0x97,0x77,
  0x94,0xc9,0x3c,0xbe,0xc,0xa6,0x7d,0xc9,0x6b,0x5c,0xb8,0xfa,0x7b,0xbd,0xad,0x9a,
  0x7b,0xcb,0xb7,0xcd,0x55,0x8b,0x81,0x14,0xcf,0x6,0xc5,0x69,0xd9,0x7e,0x8f,0x5b,
  0x46,0xa5,0xcf,0xea,0x6d,0xb9,0x62,0xf4,0x62,0xb1,0xce,0x26,0x45,0xa7,0xb6,0x7e,
  0xb4,0x91,0xeb,0xd,0x82,0xfb,0xda,0xe7,0x80,0x8a,0xa0,0xe1,0xa1,0x22,0x67,0x46,
  0x46,0x92,0x82,0x82,0x42,0x96,0x31,0x50,0x84,0xc8,0xa0,0x2a,0x7a,0x45,0x2,0xe0,
  0x34,0xe0,0x1e,0x9c,0xe1,0x5b,0xa,0xe6,0xbc,0xc1,0xf2,0xcd,0xf5,0xc9,0xf8,0x8e,
  0xa1,0xe7,0x2e,0x17,0xce,0xf0,0x2e,0x52,0xe2,0xbe,0x6b,0x0,0x23,0x76,0xf8,0x51,
  0x3b,0xbf,0x30,0x9b,0x44,0xb6,0x5b,0x66,0x6d,0xd9,0xcb,0x2e,0x2a,0x49,0x26,0xeb,
  0x58,0x99,0x50,0x8e,0x9d,0xb7,0x61,0x14,0x8e,0x2a,0x63,0x9d,0x1e,0xfb,0x10,0x46,
  0x3b,0x28,0xd2,0x3,0x72,0x9b,0x11,0xf1,0xe,0x87,0xb3,0x28,0x7c,0x59,0xa9,0x9e,
  0xef,0xc0,0x7c,0xc8,0x10,0xdb,0x92,0xec,0xb9,0xb8,0x16,0x98,0x54,0x8c,0xc8,0x80,
  0xf7,0xc0,0xa5,0x19,0x4d,0x7e,0xdd,0xac,0xab,0xfe,0x57,0xd7,0x2a,0x2e,0xe0,0x6,
  0xb,0xe8,0xdf,0x8,0x13,0x20,0x92,0x6f,0xb8,0x5b,0xbc,0x66,0x4a,0x3,0x93,0x5,
  0x66,0x23,0xb5,0x60,0xe1,0x4b,0x66,0x9d,0x47,0x58,0xb5,0xec,0x54,0x2e,0xd6,0x92,
  0xa6,0x50,0x94,0x88,0xd8,0x49,0xde,0x60,0x62,0xe4,0xb4,0x59,0x4c,0xdb,0xe1,0xf1,
  0xca,0x62,0xda,0x56,0xca,0x47,0xf6,0x6d,0x58,0xd7,0x64,0x1d,0x61,0x1a,0xcb,0x4d,
  0x63,0xb,0x42,0x59,0x78,0x12,0x55,0xc0,0x13,0xf3,0xab,0xcb,0x58,0xe2,0x92,0x2d,
  0xcf,0x56,0x4,0x99,0x38,0x6e,0xa6,0x78,0xa5,0x14,0xf8,0xa2,0xcf,0xfc,0xd5,0xc6,
  0xe9,0x24,0xe5,0xc5,0x3e,0xe1,0x8a,0x6f,0xd4,0x16,0x60,0x5c,0x4c,0xbc,0x49,0xa0,
  0xb7,0x97,0xdf,0xc5,0x82,0x9,0x2c,0xc5,0x88,0x20,0x5e,0x7f,0xe0,0x10,0x1,0x20,
  0x2,0x77,0x3e,0x5,0x9a,0xef,0x5c,0x38,0x2c,0x8,0xbc,0x88,0xb,0x58,0x6,0x3,
  0x1f,0x48,0x1,0x91,0x10,0x34,0x6e,0x7a,0xd1,0xbd,0x39,0x92,0x7f,0x49,0xff,0x70,
  0x99,0xc3,0x14,0x2a,0x60,0x72,0x0,0x85,0xac,0xcb,0x40,0x18,0x0,0x55,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kubrick
  0x0,0x7,
  0x2,0xb9,0x8f,0x7b,
  0x0,0x6b,
  0x0,0x75,0x0,0x62,0x0,0x72,0x0,0x69,0x0,0x63,0x0,0x6b,
    // kubrickui.rc
  0x0,0xc,
  0x8,0x7c,0xb4,0x63,
  0x0,0x6b,
  0x0,0x75,0x0,0x62,0x0,0x72,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0x18,0xe9,0xa0,0x80,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0x18,0xe9,0xa0,0x80,
  // :/kxmlgui5/kubrick
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0x18,0xe9,0xa0,0x80,
  // :/kxmlgui5/kubrick/kubrickui.rc
  0x0,0x0,0x0,0x2a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0x18,0xe9,0xa0,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kubrick)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kubrick)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kubrick)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kubrick)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kubrick)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kubrick)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
